"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""
# info_txt = requests.get('https://raw.githubusercontent.com/Superior-GitHub/superior6564/main/superior6564/info.txt')
# out_1 = open("info.txt", "wb")
# out_1.write(info_txt.content)
# out_1.close()
# with open('info.txt') as f:
#     sum_letters = ""
#     version = []
#     while sum_letters != "Version":
#         line = f.readline()
#         if len(line) >= 7:
#             sum_letters = ""
#             for i in range(7):
#                 sum_letters += line[i]
#                 if sum_letters == "Version":
#                     for j in range(5):
#                         version.append(line[j + 22])

__author__ = 'Superior_6564'
# __version__ = version[0] + version[1] + version[2] + version[3] + version[4]
# __version__ = version
__email__ = 'vip.klochayil@gmail.com'



"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""
from IPython.display import Image, display
import requests


with open("degget_elite.jpg", "wb") as f:
    f.write(requests.get('https://github.com/Superior-GitHub/superior6564/raw/main/superior6564/degit_Elite.jpg').content)


def show(check: int):
    if check == 1:
        display(Image(filename="degget_elite.jpg"))
    elif check == 0:
        print("This method only works in web compilers")




"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""
import subprocess
import sys
import time


def install(package: str, check=True):
    subprocess.check_call([sys.executable, "-m", "pip", "install", package])
    subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", package])
    if check:
        print(f"Library {package} installed.")


def pip_upgrade():
    subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", "pip"])


def required():
    install("python-time", check=False)
    require = ["requests", "ipython", "progress", "dearpygui"]
    print("Installing the required libraries...")
    for i in range(len(require)):
        install(require[i])
        print(f"Status: {i + 1} of {len(require)}")
        time.sleep(1)
    print("Installation is complete.")



#!/usr/bin/env python

from io import open
from setuptools import setup, find_packages
import requests


"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""


# with open('README.md') as f:
#     previous_version = f.readline()[22:].strip()
#     if int(previous_version[4]) < 9:
#         previous_num = previous_version[4]
#         new_num = str(int(previous_version[4]) + 1)
#         new_version = previous_version[:-1] + new_num
#     elif int(previous_version[2]) < 9:
#         previous_num = previous_version[2]
#         new_num = str(int(previous_version[2]) + 1)
#         new_version = previous_version[0:2] + new_num + ".0"
#     elif int(previous_version[0]) < 9:
#         previous_num = previous_version[0]
#         new_num = str(int(previous_version[0]) + 1)
#         new_version = new_num + "0.0"
#     test_description = f.read()
# version = new_version

version = '0.2.2'
# 0.1.9

with open('README.md') as f:
    line_dict = {"Theme": f.readline(), "Space_1": f.readline(), "Name": f.readline(),
                 "Space_2": f.readline(), "Version": f.readline()[:9], "Everything_else": f.read()}

with open('README.md', "w") as f:
    write_readme = line_dict["Theme"] + line_dict["Space_1"] + line_dict["Name"] + \
                   line_dict["Space_2"] + line_dict["Version"] + version + "\n" + line_dict["Everything_else"]
    f.write(write_readme)

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='superior6564',
    version=version,

    author='Superior_6564',
    author_email='vip.klochayil@gmail.com',

    description=(
        u'Python library which maybe will help to people. '
        u'Before using you need to run packages.required()'
    ),
    long_description=long_description,
    # long_description_content_type='text/markdown',

    url='https://github.com/Superior-GitHub/Superior6564',
    download_url='https://github.com/Superior-GitHub/Superior6564/archive/refs/heads/main.zip'.format(version),

    license='Apache License, Version 2.0, see LICENSE file',

    packages=find_packages(),
    install_requires=['', ''],

    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ]
)



"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""
import os
import requests


with open("readme.md", "wb") as f:
    f.write(requests.get('https://raw.githubusercontent.com/Superior-GitHub/superior6564/main/README.md').content)


def get_info():
    path = os.getcwd() + "/readme.md"
    line_need = []
    name_need = ["Name", "Vers", "Desc", "Home", "Down", "Wiki", "Auth", "Lice"]
    with open(path) as f:
        for i in range(19):
            # line = f.readline().replace("\n", "")
            line = f.readline()
            if line[:4] in name_need:
                line_need.append(line)
    with open(path) as f:
        dictionary = {"Name": line_need[0], "Version": line_need[1], "Description": line_need[2],
                      "Home-Page": line_need[3], "Download-URL": line_need[4], "Wiki": line_need[5],
                      "Author": line_need[6], "Author-email": line_need[7], "License": line_need[8]}
        print(dictionary["Name"] + dictionary["Version"] + dictionary["Description"] +
              dictionary["Home-Page"] + dictionary["Download-URL"] + dictionary["Wiki"] +
              dictionary["Author"] + dictionary["Author-email"] + dictionary["License"])
